#!/usr/bin/env node

const inquirer = require('inquirer')
const path = require('path')
const { execSync } = require('child_process')

const CURRENT_DIR_PATH = process.cwd()
const REPOSITORY_URL = `https://gitlab.com/monkkey/express-typescript`

const PROJECT_NAME_KEY = 'project-name'

const QUESTIONS = [
    {
        name: PROJECT_NAME_KEY,
        type: 'input',
        message: 'Project name:',
        validate: function(input) {
            // Project name may only include letters, numbers, underscores and hashes.
            if (/^([A-Za-z\-\_\d])+$/.test(input)) {
                return true
            }

            return false
        },
    },
]

inquirer
    .prompt(QUESTIONS)
    .then(createProjectFromAnswers(REPOSITORY_URL, CURRENT_DIR_PATH))

function createProjectFromAnswers(repositoryUrl, currentDirPath) {
    return (answers) => {
        const projectName = answers[PROJECT_NAME_KEY]
        const projectPath = path.join(currentDirPath, projectName)
        cloneRepo(repositoryUrl, projectPath)
    }
}

function cloneRepo(repositoryUrl, targetPath) {
    try {
        execSync(`git clone ${repositoryUrl} ${targetPath}`)
        execSync(`rm -rf ${path.join(targetPath, '.git')}`)
    } catch (error) {
        execSync(`rm -rf ${targetPath}`)
    }
}
